@@ -24,13 +24,13 @@ use crate::{syntax_pos::Mark, SyntaxContext};
 pub enum PluginError {
     /// Occurs when failed to convert size passed from host / guest into usize
     /// or similar for the conversion. This is an internal error rasied via
-    /// plugin_macro, noramlly plugin author should not raise this manually.
+    /// plugin_macro, normally plugin author should not raise this manually.
     SizeInteropFailure(String),
     /// Occurs when failed to reconstruct a struct from `Serialized`.
     Deserialize(String),
     /// Occurs when failed to serialize a struct into `Serialized`.
     /// Unlike deserialize error, this error cannot forward any context for the
-    /// raw bytes: when serialze failed, there's nothing we can pass between
+    /// raw bytes: when serialize failed, there's nothing we can pass between
     /// runtime.
     Serialize(String),
 }
@@ -104,7 +104,7 @@ impl Serialized {
             .with_context(|| format!("failed to deserialize `{}`", type_name::<W>()))
     }
 
-    /// Convinient wrapper to Serialized::* to construct actual struct from raw
+    /// Convenient wrapper to Serialized::* to construct actual struct from raw
     /// ptr. This is common workflow on both of runtime (host / plugin) to
     /// deserialize struct from allocated / copied ptr.
     ///
@@ -126,4 +126,34 @@ impl Serialized {
         let serialized = Serialized::new_for_plugin(raw_ptr_bytes, raw_allocated_ptr_len);
         Serialized::deserialize(&serialized)
     }
+
+    /// Deserialize `Fallible` struct from raw ptr. This is similar to
+    /// `deserialize_from_ptr` but for the struct requires bounds to the
+    /// SharedSerializeRegistry which cannot be Infallible. Internally this does
+    /// not call deserialize with Infallible deserializer, use
+    /// SharedDeserializeMap instead.
+    ///
+    /// # Safety
+    /// This is unsafe by construting bytes slice from raw ptr also deserialize
+    /// it without slice bound check.
+    pub unsafe fn deserialize_from_ptr_fallible<W>(
+        raw_allocated_ptr: *const u8,
+        raw_allocated_ptr_len: i32,
+    ) -> Result<W, Error>
+    where
+        W: rkyv::Archive,
+        W::Archived: rkyv::Deserialize<W, rkyv::de::deserializers::SharedDeserializeMap>,
+    {
+        // Create serialized bytes slice from ptr
+        let raw_ptr_bytes = unsafe {
+            std::slice::from_raw_parts(raw_allocated_ptr, raw_allocated_ptr_len.try_into()?)
+        };
+
+        let serialized = Serialized::new_for_plugin(raw_ptr_bytes, raw_allocated_ptr_len);
+
+        unsafe {
+            rkyv::from_bytes_unchecked(serialized.as_ref())
+                .map_err(|err| Error::msg("Failed to deserialize given ptr"))
+        }
+    }
 }
